# kubernety

Graphical interface for Kubernetes API in your console

<table>
  <tr>
    <td>
      <img src="https://github.com/marianocarrazana/kubernety/assets/17238076/4a955a2a-faec-412c-a9fa-dc6269eb6be0"/>
    </td>
  </tr>
</table>

## Installation

### From source

```shell
git clone git@github.com:marianocarrazana/kubernety.git
cd kubernety
pip install -e .
# update only:
git pull
```

### From pip

```shell
pip install -U kubernety
```

## Usage

Run on your console:

```shell
kubernety
```

### **Enjoy it!**
